ImageSetLayer
=============

.. currentmodule:: wwt_data_formats.layers

.. autoclass:: ImageSetLayer
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ImageSetLayer.extension
      ~ImageSetLayer.image_set
      ~ImageSetLayer.override_default

   .. rubric:: Attributes Documentation

   .. autoattribute:: extension
   .. autoattribute:: image_set
   .. autoattribute:: override_default
